@@ -1,6 +1,6 @@
 !     
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2021 Guido Dhondt
+!     Copyright (C) 1998-2022 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
 !     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 !     
       subroutine acctube_one(node1,node2,nodem,nelem,lakon,kon,ipkon,
-     &        nactdog,identity,ielprop,prop,iflag,v,xflow,f,
+     &        nactdog,identity,ielprop,prop,kflag,v,xflow,f,
      &        nodef,idirf,df,cp,r,physcon,dvi,numf,set,mi,ider,
      &        ttime,time,iaxial,iplausi)
 !
@@ -33,7 +33,7 @@
       character*81 set(*)
 !
       integer node1,node2,nodem,nelem,kon(*),ipkon(*),nactdog(0:3,*),
-     &  ielprop(*),iflag,nodef(5),idirf(5),numf,mi(*),ider,iaxial,
+     &  ielprop(*),kflag,nodef(5),idirf(5),numf,mi(*),ider,iaxial,
      &  iplausi
 !
       real*8 prop(*),v(0:mi(2),*),xflow,f,df(5),cp,r,physcon(*),dvi,
