@@ -1,6 +1,6 @@
 !
 !     CalculiX - A 3-dimensional finite element program
-!     Copyright (C) 1998-2021 Guido Dhondt
+!     Copyright (C) 1998-2022 Guido Dhondt
 !     
 !     This program is free software; you can redistribute it and/or
 !     modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
 !     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 !     
       subroutine carbon_seal(node1,node2,nodem,nelem,lakon,
-     &     nactdog,identity,ielprop,prop,iflag,v,xflow,f,
+     &     nactdog,identity,ielprop,prop,kflag,v,xflow,f,
      &     nodef,idirf,df,R,physcon,dvi,numf,set,mi,ttime,time,
      &     iaxial,iplausi)
 !     
@@ -33,7 +33,7 @@
       character*81 set(*)
 !     
       integer nelem,nactdog(0:3,*),node1,node2,nodem,numf,
-     &     ielprop(*),nodef(*),idirf(*),index,iflag,
+     &     ielprop(*),nodef(*),idirf(*),index,kflag,
      &     inv,mi(*),iaxial,iplausi
 !
       real*8 prop(*),v(0:mi(2),*),xflow,f,df(*),R,d,dl,
@@ -41,7 +41,7 @@
 !
 !
 !     
-      if(iflag.eq.0) then
+      if(kflag.eq.0) then
          identity=.true.
 !     
          if(nactdog(2,node1).ne.0)then
@@ -52,7 +52,7 @@
             identity=.false.
          endif
 !     
-      elseif(iflag.eq.1)then
+      elseif(kflag.eq.1)then
          if(v(1,nodem).ne.0.d0) then
             xflow=v(1,nodem)
             return
@@ -89,7 +89,7 @@
             write(*,*) 'check input file'
          endif
 !     
-      elseif(iflag.eq.2)then
+      elseif(kflag.eq.2)then
 !     
          numf=4
          p1=v(2,node1)
@@ -137,7 +137,7 @@
 !       
          endif
 
-      elseif(iflag.eq.3) then
+      elseif(kflag.eq.3) then
          p1=v(2,node1)
          p2=v(2,node2)
          if(p1.ge.p2) then
