@@ -1,5 +1,5 @@
 /*     CalculiX - A 3-dimensional finite element program                 */
-/*              Copyright (C) 1998-2021 Guido Dhondt                          */
+/*              Copyright (C) 1998-2022 Guido Dhondt                          */
 
 /*     This program is free software; you can redistribute it and/or     */
 /*     modify it under the terms of the GNU General Public License as    */
@@ -15,8 +15,7 @@
 /*     along with this program; if not, write to the Free Software       */
 /*     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         */
 
-/*     A parallel copy of arrays which depent on active element 	 */
-
+/*     parallellization of the calculation of the damping forces */
 
 #include <unistd.h>
 #include <stdio.h>
@@ -25,7 +24,7 @@
 #include <pthread.h>
 #include "CalculiX.h"
 
-static ITG *neapar=NULL,*nebpar=NULL,*mt1,*nactdof1;
+static ITG *nkapar=NULL,*nkbpar=NULL,*mt1,*nactdof1;
 
 static double *aux21,*v1,*vini1;
 
@@ -40,24 +39,24 @@ void dam1parll(ITG *mt,ITG *nactdof,double *aux2,double *v,
 
     pthread_t tid[*num_cpus];
 
-    /* determining the element bounds in each thread */
+    /* determining the node bounds in each thread */
 
-    NNEW(neapar,ITG,*num_cpus);
-    NNEW(nebpar,ITG,*num_cpus);
+    NNEW(nkapar,ITG,*num_cpus);
+    NNEW(nkbpar,ITG,*num_cpus);
 
-    /* dividing the element number range into num_cpus equal numbers of 
+    /* dividing the node number range into num_cpus equal numbers of 
        active entries.  */
 
     idelta=(ITG)floor(*nk/(double)(*num_cpus));
     isum=0;
     for(i=0;i<*num_cpus;i++){
-	neapar[i]=isum;
+	nkapar[i]=isum;
 	if(i!=*num_cpus-1){
 	    isum+=idelta;
 	}else{
 	    isum=*nk;
 	}
-	nebpar[i]=isum;
+	nkbpar[i]=isum;
     }
 
     /* create threads and wait */
@@ -72,20 +71,20 @@ void dam1parll(ITG *mt,ITG *nactdof,double *aux2,double *v,
     }
     for(i=0; i<*num_cpus; i++)  pthread_join(tid[i], NULL);
 
-    SFREE(ithread);SFREE(neapar);SFREE(nebpar);
+    SFREE(ithread);SFREE(nkapar);SFREE(nkbpar);
 
 }
 
-/* subroutine for multithreading of copyparll */
+/* subroutine for multithreading of dam1parll */
 
 void *dam1parllmt(ITG *i){
 
-    ITG nea,neb,k,j;
+    ITG nka,nkb,k,j;
 
-    nea=neapar[*i];
-    neb=nebpar[*i];
+    nka=nkapar[*i];
+    nkb=nkbpar[*i];
 
-    for(k=nea;k<neb;k++){
+    for(k=nka;k<nkb;k++){
 	for(j=1;j<*mt1;++j){
 	    if(nactdof1[*mt1*k+j]>0){
 		aux21[nactdof1[*mt1*k+j]-1]=v1[*mt1*k+j]-vini1[*mt1*k+j];
